==> patch-3.8.1-ONex-OMS-wms-source-PHP5.6.tar.gz: ShopexErp/app/desktop/model/users.php <==
<?php
/**
 * ShopEx licence
 *
 * @copyright  Copyright (c) 2005-2010 ShopEx Technologies Inc. (http://www.shopex.cn)
 * @license  http://ecos.shopex.cn/ ShopEx License
 */

/**
 * mdl_user
 *
 * @uses modelFactory
 * @package
 * @version $Id: mdl.user.php 1985 2008-04-28 06:36:02Z flaboy $
 * @copyright 2003-2007 ShopEx
 * @author Likunpeng <leoleegood@zovatech.com>
 * @license Commercial
 */

class desktop_mdl_users extends dbeav_model{

   var $has_parent = array(
        'pam_account' => 'account@pam'
    );
    var $has_many = array(
        'roles' => 'hasrole:replace',
    );
   var $subSdf = array(
        'default' => array(
            'pam_account:account@pam' => array('*'),
         ),
         'delete' => array(
             'pam_account:account@pam' => array('*'),
             'roles' => array('*'),
         )
    );
   function pre_recycle($data){
        $obj_pam = app::get('pam')->model('account');
        $falg = true;
        $users = kernel::single('desktop_user');
        foreach($data as $val){
            if($users->user_id == $val['user_id']){
                $this->recycle_msg = app::get('desktop')->_('自己不能删除自己');
                $falg = false;
                break;
            }else{
                if($val['user_id'] == 1){
                    $this->recycle_msg = app::get('desktop')->_('子账号不能删除超级管理员');
                    $falg = false;
                    break;
                    
                }
            }
        }
        return $falg;
   }

  function pre_restore(&$data,$restore_type='add'){
         if(!($this->check_name($data['pam_account']['login_name']))){
             $data['need_delete'] = true;
             return true;
         }
         else{
             if($restore_type == 'add'){
                    $new_name = $data['pam_account']['login_name'].'_1';
                    while($this->check_name($new_name)){
                        $new_name = $new_name.'_1';
                    }
                    $data['pam_account']['login_name'] = $new_name;
                    $data['need_delete'] = true;
                 return true;
             }
             if($restore_type == 'none'){
                 $data['need_delete'] = false;
                 return true;
             }
         }
    }

    function editUser(&$data){
        if($data['userpass']){
            //$data[':account@pam']['login_password'] = md5(trim($data['userpass']));
           $data[':account@pam']['login_password'] = pam_encrypt::get_encrypted_password(trim($data['userpass']),pam_account::get_account_type($this->app->app_id));
        }
        /*
        else{
            $data[':account@pam']['login_password'] = trim($data['oldpass']);
        }
       */
        $data['pam_account']['account_type'] = pam_account::get_account_type($this->app->app_id);
        $data['pam_account']['createtime'] = time();

        return parent::save($data);
    }
    ###

    ##检查用户名
    function check_name($login_name){
        $pam = app::get('pam')->model('account');
        $account_type = pam_account::get_account_type($this->app->app_id);
        $aData = $pam->getList('*',array('login_name' => $login_name,'account_type' =>$account_type ));
        $result = $aData[0]['account_id'];
        if($result){
            return true;
        }
        else{
            return false;
        }
    }

   ###更新登陆信息

   function update_admin($user_id){

     $aUser = $this->dump($user_id,'*');
     $sdf[':account@pam']['account_id'] = $user_id;
     $sdf['lastlogin'] = time();
     $sdf['logincount'] = $aUser['logincount']+1;
     $this->save($sdf);
   }

   ##检查
   function validate($aData,&$msg){

        if($aData['pam_account']['login_name']==''||$aData['pam_account']['login_password']==''||$aData['name']==''){
            $msg = app::get('desktop')->_('必填项不能为空');
            return fasle;
        }

        $userLib = kernel::single('desktop_user');
        if(!$userLib->validPassWord($aData['pam_account']['login_password'], $error_msg)){
            $msg = app::get('desktop')->_($error_msg);
            return false;
        }

        if($aData['pam_account']['login_password']!=$_POST['re_password']){
            $msg = app::get('desktop')->_('两次密码输入不一致');
            return false;
        }

        $result = $this->check_name($aData['pam_account']['login_name']);
        if($result){
              $msg = app::get('desktop')->_('该用户名已存在');
              return false;

          }
         return true;
     }

     //获取工作组细分
    function detail_per($check_id,$user_id){
        $roles = $this->app->model('roles');
        $menus =$this->app->model('menus');
        $aPermission =array();
        if(!$check_id) {
            echo '';exit;
        }
        foreach($check_id as $val){
            $result = $roles->dump($val);
            $data = unserialize($result['workground']);
            foreach((array)$data as $row){
                $aPermission[] = $row;
            }
        }
        $aPermission = array_unique($aPermission);
        if(!$aPermission){
            echo '';exit;
        }
        $addonmethod = array();
        foreach((array)$aPermission as $val){
            $sdf = $menus->dump(array('menu_type' => 'permission','permission' => $val));
            $addon = unserialize($sdf['addon']);
            if($addon['show']&&$addon['save']){  //如果存在控制
                if(!in_array($addon['show'],$addonmethod)){
                    $access = explode(':',$addon['show']);
                    $classname = $access[0];
                    $method = $access[1];
                    $obj = kernel::single($classname);
                    $html.=$obj->$method($user_id);
                }
                $addonmethod[] = $addon['show'];
            }
            else{
                echo '';
            }
        }
        return $html;
    }

    //保存工作组细分
    function save_per($aData){
        $workgrounds = $aData['role'];
        $menus = $this->app->model('menus');
        $roles =  $this->app->model('roles');
        foreach($workgrounds as $val){
            $result = $roles->dump($val);
            $data = unserialize($result['workground']);
            foreach((array)$data as $row){
                $aPermission[] = $row;
            }
        }
        $aPermission = array_unique($aPermission);
        if($aPermission){
            $addonmethod = array();
            foreach((array)$aPermission as $key=>$val){
                $sdf = $menus->dump(array('menu_type' => 'permission','permission' => $val));
                $addon = unserialize($sdf['addon']);
                if($addon['show']&&$addon['save']){  //如果存在控制
                    if(!in_array($addon['save'],$addonmethod)){
                        $access = explode(':',$addon['save']);
                        $classname = $access[0];
                        $method = $access[1];
                        $obj = kernel::single($classname);
                        $obj->$method($aData['user_id'],$aData);
                    }
                    $addonmethod[] = $addon['save'];
                }
            }
        }

        }
    //获取工作组细分
    function detail_per_group($check_id,$user_id){
        $roles = $this->app->model('roles');
        $menus =$this->app->model('menus');
        $aPermission =array();
        if(!$check_id) {
            echo '';exit;
        }
        foreach($check_id as $val){
            $result = $roles->dump($val);
            $data = unserialize($result['workground']);
            foreach((array)$data as $row){
                $aPermission[] = $row;
            }
        }
        $aPermission = array_unique($aPermission);
        if(!$aPermission){
            echo '';exit;
        }
        $addonmethod = array();
        foreach((array)$aPermission as $val){
            $sdf = $menus->dump(array('menu_type' => 'permission','permission' => $val));
            $addon = unserialize($sdf['addon']);
            if($addon['show']&&$addon['save']){  //如果存在控制
                if(!in_array($addon['show'],$addonmethod)){
                    $access = explode(':',$addon['show']);
                    $classname = $access[0];
                    $method = $access[1];
                    $obj = kernel::single($classname);
                    $info = $obj->$method($user_id);
                    if($addon['show']=='ome_roles:show_branch'){
                        $html['branch'] = $info;
                    }else{
                        $html['order'] = $info;
                    }
                }

                $addonmethod[] = $addon['show'];
            }
            else{
                echo '';
            }
        }
        return $html;
    }

    /**
     *
     * 彻底删除管理员的同时，清除相关的角色权限关联信息
     * @param int $userid
     */
    function suf_delete($userid){
        $hasRoleObj = app::get('desktop')->model('hasrole');
        $hasRoleObj->delete(array('user_id'=>$userid));
        return true;
    }
}

==> patch-4.2.0-ONex-OMS-wms-source-PHP5.3.tar.gz: ShopexErp/app/desktop/model/users.php <==
<?php
/**
 * ShopEx licence
 *
 * @copyright  Copyright (c) 2005-2010 ShopEx Technologies Inc. (http://www.shopex.cn)
 * @license  http://ecos.shopex.cn/ ShopEx License
 */

/**
 * mdl_user
 *
 * @uses modelFactory
 * @package
 * @version $Id: mdl.user.php 1985 2008-04-28 06:36:02Z flaboy $
 * @copyright 2003-2007 ShopEx
 * @author Likunpeng <leoleegood@zovatech.com>
 * @license Commercial
 */

class desktop_mdl_users extends dbeav_model{

   var $has_parent = array(
        'pam_account' => 'account@pam'
    );
    var $has_many = array(
        'roles' => 'hasrole:replace',
    );
   var $subSdf = array(
        'default' => array(
            'pam_account:account@pam' => array('*'),
         ),
         'delete' => array(
             'pam_account:account@pam' => array('*'),
             'roles' => array('*'),
         )
    );
   function pre_recycle($data){
        $obj_pam = app::get('pam')->model('account');
        $falg = true;
        $users = kernel::single('desktop_user');
        foreach($data as $val){
            if($users->user_id == $val['user_id']){
                $this->recycle_msg = app::get('desktop')->_('自己不能删除自己');
                $falg = false;
                break;
            }else{
                if($val['user_id'] == 1){
                    $this->recycle_msg = app::get('desktop')->_('子账号不能删除超级管理员');
                    $falg = false;
                    break;
                    
                }
            }
        }
        return $falg;
   }

  function pre_restore(&$data,$restore_type='add'){
         if(!($this->check_name($data['pam_account']['login_name']))){
             $data['need_delete'] = true;
             return true;
         }
         else{
             if($restore_type == 'add'){
                    $new_name = $data['pam_account']['login_name'].'_1';
                    while($this->check_name($new_name)){
                        $new_name = $new_name.'_1';
                    }
                    $data['pam_account']['login_name'] = $new_name;
                    $data['need_delete'] = true;
                 return true;
             }
             if($restore_type == 'none'){
                 $data['need_delete'] = false;
                 return true;
             }
         }
    }

    function editUser(&$data){
        if($data['userpass']){
            //$data[':account@pam']['login_password'] = md5(trim($data['userpass']));
           $data[':account@pam']['login_password'] = pam_encrypt::get_encrypted_password(trim($data['userpass']),pam_account::get_account_type($this->app->app_id));
        }
        /*
        else{
            $data[':account@pam']['login_password'] = trim($data['oldpass']);
        }
       */
        $data['pam_account']['account_type'] = pam_account::get_account_type($this->app->app_id);
        $data['pam_account']['createtime'] = time();

        return parent::save($data);
    }
    ###

    ##检查用户名
    function check_name($login_name){
        $pam = app::get('pam')->model('account');
        $account_type = pam_account::get_account_type($this->app->app_id);
        $aData = $pam->getList('*',array('login_name' => $login_name,'account_type' =>$account_type ));
        $result = $aData[0]['account_id'];
        if($result){
            return true;
        }
        else{
            return false;
        }
    }

   ###更新登陆信息

   function update_admin($user_id){

     $aUser = $this->dump($user_id,'*');
     $sdf[':account@pam']['account_id'] = $user_id;
     $sdf['lastlogin'] = time();
     $sdf['logincount'] = $aUser['logincount']+1;
     $this->save($sdf);
   }

   ##检查
   function validate($aData,&$msg){

        if($aData['pam_account']['login_name']==''||$aData['pam_account']['login_password']==''||$aData['name']==''){
            $msg = app::get('desktop')->_('必填项不能为空');
            return fasle;
        }

        $userLib = kernel::single('desktop_user');
        if(!$userLib->validPassWord($aData['pam_account']['login_password'], $error_msg)){
            $msg = app::get('desktop')->_($error_msg);
            return false;
        }

        if($aData['pam_account']['login_password']!=$_POST['re_password']){
            $msg = app::get('desktop')->_('两次密码输入不一致');
            return false;
        }
        if(strlen($aData['mobile'])!='11' || !is_numeric($aData['mobile'])){
            $msg = app::get('desktop')->_('手机号码格式不正确');
            return false;
        }
        $result = $this->check_name($aData['pam_account']['login_name']);

        if($result){
              $msg = app::get('desktop')->_('该用户名已存在');
              return false;

          }
         return true;
     }

     //获取工作组细分
    function detail_per($check_id,$user_id){
        $roles = $this->app->model('roles');
        $menus =$this->app->model('menus');
        $aPermission =array();
        if(!$check_id) {
            echo '';exit;
        }
        foreach($check_id as $val){
            $result = $roles->dump($val);
            $data = unserialize($result['workground']);
            foreach((array)$data as $row){
                $aPermission[] = $row;
            }
        }
        $aPermission = array_unique($aPermission);
        if(!$aPermission){
            echo '';exit;
        }
        $addonmethod = array();
        foreach((array)$aPermission as $val){
            $sdf = $menus->dump(array('menu_type' => 'permission','permission' => $val));
            $addon = unserialize($sdf['addon']);
            if($addon['show']&&$addon['save']){  //如果存在控制
                if(!in_array($addon['show'],$addonmethod)){
                    $access = explode(':',$addon['show']);
                    $classname = $access[0];
                    $method = $access[1];
                    $obj = kernel::single($classname);
                    $html.=$obj->$method($user_id);
                }
                $addonmethod[] = $addon['show'];
            }
            else{
                echo '';
            }
        }
        return $html;
    }

    //保存工作组细分
    function save_per($aData){
        $workgrounds = $aData['role'];
        $menus = $this->app->model('menus');
        $roles =  $this->app->model('roles');
        foreach($workgrounds as $val){
            $result = $roles->dump($val);
            $data = unserialize($result['workground']);
            foreach((array)$data as $row){
                $aPermission[] = $row;
            }
        }
        $aPermission = array_unique($aPermission);
        if($aPermission){
            $addonmethod = array();
            foreach((array)$aPermission as $key=>$val){
                $sdf = $menus->dump(array('menu_type' => 'permission','permission' => $val));
                $addon = unserialize($sdf['addon']);
                if($addon['show']&&$addon['save']){  //如果存在控制
                    if(!in_array($addon['save'],$addonmethod)){
                        $access = explode(':',$addon['save']);
                        $classname = $access[0];
                        $method = $access[1];
                        $obj = kernel::single($classname);
                        $obj->$method($aData['user_id'],$aData);
                    }
                    $addonmethod[] = $addon['save'];
                }
            }
        }

        }
    //获取工作组细分
    function detail_per_group($check_id,$user_id){
        $roles = $this->app->model('roles');
        $menus =$this->app->model('menus');
        $aPermission =array();
        if(!$check_id) {
            echo '';exit;
        }
        foreach($check_id as $val){
            $result = $roles->dump($val);
            $data = unserialize($result['workground']);
            foreach((array)$data as $row){
                $aPermission[] = $row;
            }
        }
        $aPermission = array_unique($aPermission);
        if(!$aPermission){
            echo '';exit;
        }
        $addonmethod = array();
        foreach((array)$aPermission as $val){
            $sdf = $menus->dump(array('menu_type' => 'permission','permission' => $val));
            $addon = unserialize($sdf['addon']);
            if($addon['show']&&$addon['save']){  //如果存在控制
                if(!in_array($addon['show'],$addonmethod)){
                    $access = explode(':',$addon['show']);
                    $classname = $access[0];
                    $method = $access[1];
                    $obj = kernel::single($classname);
                    
                    $info = $obj->$method($user_id);
                    if($addon['show']=='ome_roles:show_branch')
                    {
                        $html['branch'] = $info;
                    }
                    elseif($addon['show']=='ome_roles:show_o2o_branch')
                    {
                        $html['o2o_branch'] = $info;#o2o门店线下仓库
                    }
                    else{
                        $html['order'] = $info;
                    }
                }

                $addonmethod[] = $addon['show'];
            }
            else{
                echo '';
            }
        }
        return $html;
    }

    /**
     *
     * 彻底删除管理员的同时，清除相关的角色权限关联信息
     * @param int $userid
     */
    function suf_delete($userid){
        $hasRoleObj = app::get('desktop')->model('hasrole');
        $hasRoleObj->delete(array('user_id'=>$userid));
        return true;
    }

    public function modifier_mobile($row){
        if($row){
            return (kernel::single('desktop_user')->is_super())?$row:substr_replace($row,"****",3,4);
        }else{
            return $row;
        }
    }
    
    function searchOptions(){
        $parentOptions = parent::searchOptions();
        $childOptions = array(
                'login_name'=>app::get('ome')->_('用户名'),
                'name'=>app::get('ome')->_('姓名'),
        );
        return $Options = array_merge($parentOptions,$childOptions);
    }
    
    function _filter($filter,$tableAlias=null,$baseWhere=null){
        $where = array();
        //pam_account表 用户名
        if(isset($filter['login_name'])){
            $mdl_pam_account = app::get('pam')->model('account');
            $rs_pam_account = $mdl_pam_account->dump(array("login_name"=>addslashes($filter['login_name'])));
            if(!empty($rs_pam_account)){
                $where[] = "user_id=".$rs_pam_account["account_id"];
            }else{
                $where[] = "user_id=-1";
            }
            unset($filter['login_name']);
        }
        if(isset($filter['name'])){
            $where[] = "name='".addslashes($filter['name'])."'";
            unset($filter['name']);
        }
        //desktop_users表 姓名
        $sWhere = parent::_filter($filter,$tableAlias,$baseWhere);
        if(!empty($where)){
            $sWhere .= " AND ".implode(" and ",$where);
        }
        return $sWhere;
    }
    
}
